import { Component, OnInit } from '@angular/core';
import { ApiService } from '../api.service';
import {Platform} from '@ionic/angular';
import {AppMinimize} from '@ionic-native/app-minimize/ngx';

@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.scss']
})
export class LoginComponent implements OnInit {
  username = '';
  password = '';
  error: string = null;

  constructor(private apiService: ApiService, private platform: Platform, private appMinimize: AppMinimize) { }

  ngOnInit(): void {
    this.platform.backButton.subscribe(
      (t) => {
        this.appMinimize.minimize();
      }
    );
  }

  login(event): void
  {
    event.target.disabled = true;
    event.target.style.visibility = 'hidden';

    this.apiService.getAuthToken(this.username, this.password).toPromise()
      .then(
        (response) => {
          this.apiService.storeData('token', response.token);

          this.apiService.getChatToken(response.token).toPromise()
            .then(
              (chatTokenResponse) => {
                this.apiService.storeData('chatToken', chatTokenResponse.token);
                this.apiService.storeData('userId', chatTokenResponse.userId.toString());

                window.location.reload();
              }
            ).catch(
            (error) => {
              this.apiService.storeData('token', null);
              this.error = error.name + ': ' + error.message;

              event.target.disabled = false;
              event.target.style.visibility = 'visible';
            }
          );
        }
      ).catch (
      (error) => {
        this.apiService.storeData('token', null);

        switch (error.status) {
          case 401:
            this.error = 'Login fehlgeschlagen: Die Zugangsdaten sind falsch!';
            break;

          case 404:
            this.error = 'API-Fehler: Der Login-Endpunkt konnte nicht gefunden werden!';
            break;

          case 500:
            this.error = 'Server-Fehler: Bitte informiere den Techniker!';
            break;

          case 0:
            this.error = 'Verbindungsfehler: Konnte keine Verbindung zum Server herstellen!';
            break;

          default:
            this.error = 'Fehler: Etwas unfassbar grauenhaftes ist passiert!';
        }

        console.log(error);

        event.target.disabled = false;
        event.target.style.visibility = 'visible';
      }
    );
  }
}
